@@ -3,6 +3,7 @@ Record known compressors
 
 Includes utilities for determining whether or not to compress
 """
+from contextlib import suppress
 from functools import partial
 import logging
 import random
@@ -19,7 +20,7 @@ try:
 except ImportError:
     blosc = False
 
-from ..utils import ignoring, ensure_bytes
+from ..utils import ensure_bytes
 
 
 compressions = {None: {"compress": identity, "decompress": identity}}
@@ -33,12 +34,12 @@ default_compression = None
 logger = logging.getLogger(__name__)
 
 
-with ignoring(ImportError):
+with suppress(ImportError):
     import zlib
 
     compressions["zlib"] = {"compress": zlib.compress, "decompress": zlib.decompress}
 
-with ignoring(ImportError):
+with suppress(ImportError):
     import snappy
 
     def _fixed_snappy_decompress(data):
@@ -53,7 +54,7 @@ with ignoring(ImportError):
     }
     default_compression = "snappy"
 
-with ignoring(ImportError):
+with suppress(ImportError):
     import lz4
 
     try:
@@ -95,7 +96,7 @@ with ignoring(ImportError):
     default_compression = "lz4"
 
 
-with ignoring(ImportError):
+with suppress(ImportError):
     import zstandard
 
     zstd_compressor = zstandard.ZstdCompressor(
@@ -114,7 +115,7 @@ with ignoring(ImportError):
     compressions["zstd"] = {"compress": zstd_compress, "decompress": zstd_decompress}
 
 
-with ignoring(ImportError):
+with suppress(ImportError):
     import blosc
 
     compressions["blosc"] = {
