@@ -1,7 +1,6 @@
 import asyncio
 import json
 import logging
-import pickle
 import operator
 import re
 import sys
@@ -42,6 +41,14 @@ from distributed.utils_test import (  # noqa: F401
 from distributed.utils_test import loop, nodebug  # noqa: F401
 from dask.compatibility import apply
 
+if sys.version_info < (3, 8):
+    try:
+        import pickle5 as pickle
+    except ImportError:
+        import pickle
+else:
+    import pickle
+
 
 alice = "alice:1234"
 bob = "bob:1234"
@@ -2152,3 +2159,17 @@ async def test_unknown_task_duration_config(client, s, a, b):
 @gen_cluster()
 async def test_unknown_task_duration_config(s, a, b):
     assert s.idle_since == s.time_started
+
+
+@gen_cluster(client=True, timeout=1000)
+async def test_retire_state_change(c, s, a, b):
+    np = pytest.importorskip("numpy")
+    y = c.map(lambda x: x ** 2, range(10))
+    await c.scatter(y)
+    for x in range(2):
+        v = c.map(lambda i: i * np.random.randint(1000), y)
+        k = c.map(lambda i: i * np.random.randint(1000), v)
+        foo = c.map(lambda j: j * 6, k)
+        step = c.compute(foo)
+        c.gather(step)
+    await c.retire_workers(workers=[a.address])
